==> HinemosWebClient_src-1.0.1.tar.gz: HinemosWebClient_src-1.0.1/src/com/necsoft/hinemos/webclient/repository/business/GetNodeScopeTableDefineBusiness.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/



package com.necsoft.hinemos.webclient.repository.business;

import java.util.ArrayList;
import java.util.Locale;

import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.common.CssClass;
import com.necsoft.hinemos.webclient.common.DataProcess;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebHeaderInvalidException;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.json.GridHeaderJson;
import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
import com.necsoft.hinemos.webclient.repository.action.GetNodeScopeTableDefine;

/**
 * This class used for get header of NodeScope view
 * 
 * @version 1.0
 * @date 2011/12/14
 */
public class GetNodeScopeTableDefineBusiness {

    public CommonJson getNodeScopeTableDefine(Locale locale)
            throws HinemosWebException {

        // 中間変数を宣言
        ArrayList<TableColumnInfoJs> tblDefine = null;
        GridHeaderJson result = null;

        // イベントテーブルヘッダー定義データ(ScopeTableDefine)を取得
        tblDefine = GetNodeScopeTableDefine.get(locale);// .getScopeListTableDefine();

        // ...テーブルヘッダー定義データの項目数チェック
        if (tblDefine.size() != RepositoryConstants.NODE_SCOPE_TABLE_HEADER_NUM) {
            // 項目数が不足の場合
            throw new HinemosWebHeaderInvalidException(
                    "exception.repository.nodescope.header.number");
        }
        // Set first position
        tblDefine.get(0).setClasses(CssClass.GRID_FIRST_COLUMN);
        result = DataProcess.doConvertToJson(tblDefine, false, locale);

        return result;
    }
}

==> HinemosWebClient_src-2.0.0.tar.gz: HinemosWebClient_src-2.0.0/src/com/necsoft/hinemos/webclient/repository/business/GetNodeScopeTableDefineBusiness.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.repository.business;

import java.util.ArrayList;
import java.util.Locale;
import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebHeaderInvalidException;
import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
import com.necsoft.hinemos.webclient.repository.action.GetNodeScopeTableDefine;

/**
 * This class used for get header of NodeScope view
 * 
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetNodeScopeTableDefineBusiness {

    public ArrayList<TableColumnInfoJs> getNodeScopeTableDefine(Locale locale)
            throws HinemosWebException {

        // 中間変数を宣言
        ArrayList<TableColumnInfoJs> tblDefine = null;

        // イベントテーブルヘッダー定義データ(ScopeTableDefine)を取得
        tblDefine = GetNodeScopeTableDefine.get(locale);// .getScopeListTableDefine();

        // ...テーブルヘッダー定義データの項目数チェック
        if (tblDefine.size() != RepositoryConstants.NODE_SCOPE_TABLE_HEADER_NUM) {
            // 項目数が不足の場合
            throw new HinemosWebHeaderInvalidException("exception.header.number");
        }
        return tblDefine;
    }
}
